### R code from vignette source 'qpgraphSimulate.Rnw'

###################################################
### code chunk number 1: style
###################################################
BiocStyle::latex(use.unsrturl=FALSE)


###################################################
### code chunk number 2: setup
###################################################
pdf.options(useDingbats=FALSE)
options(width=80)
rm(list=ls())
try(detach("package:mvtnorm"), silent=TRUE)
try(detach("package:qtl"), silent=TRUE)


###################################################
### code chunk number 3: qpgraphSimulate.Rnw:110-116
###################################################
library(qpgraph)

args(erGraphParam)
args(erMarkedGraphParam)
args(dRegularGraphParam)
args(dRegularMarkedGraphParam)


###################################################
### code chunk number 4: qpgraphSimulate.Rnw:121-125
###################################################
erGraphParam()
erMarkedGraphParam()
dRegularGraphParam()
dRegularMarkedGraphParam()


###################################################
### code chunk number 5: qpgraphSimulate.Rnw:130-132
###################################################
showClass("graphParam")
showClass("markedGraphParam")


###################################################
### code chunk number 6: qpgraphSimulate.Rnw:143-144
###################################################
args(rgraphBAM)


###################################################
### code chunk number 7: qpgraphSimulate.Rnw:150-152
###################################################
rgraphBAM(erGraphParam())
rgraphBAM(n=2, dRegularGraphParam())


###################################################
### code chunk number 8: 3regulargraph
###################################################
set.seed(1234)
g <- rgraphBAM(dRegularMarkedGraphParam(pI=2, pY=10, d=3))
plot(g)


###################################################
### code chunk number 9: qpgraphSimulate.Rnw:190-191
###################################################
args(rUGgmm)


###################################################
### code chunk number 10: qpgraphSimulate.Rnw:202-211
###################################################
rUGgmm(dRegularGraphParam(p=4, d=2))
rUGgmm(matrix(c(0, 1, 0, 1,
                1, 0, 1, 0,
                0, 1, 0, 1,
                1, 0, 1, 0), nrow=4, byrow=TRUE))
rUGgmm(matrix(c(1, 2,
                2, 3,
                3, 4,
                4, 1), ncol=2, byrow=TRUE))


###################################################
### code chunk number 11: qpgraphSimulate.Rnw:218-221
###################################################
set.seed(12345)
gmm <- rUGgmm(dRegularGraphParam(p=4, d=2))
summary(gmm)


###################################################
### code chunk number 12: qpgraphSimulate.Rnw:225-232
###################################################
class(gmm)
names(gmm)
gmm$X
gmm$p
gmm$g
gmm$mean
gmm$sigma


###################################################
### code chunk number 13: 4cyclegraph
###################################################
plot(gmm)
round(solve(gmm$sigma), digits=1)


###################################################
### code chunk number 14: qpgraphSimulate.Rnw:267-268
###################################################
rmvnorm(10, gmm)


###################################################
### code chunk number 15: qpgraphSimulate.Rnw:273-277
###################################################
set.seed(123)
X <- rmvnorm(10000, gmm)
round(solve(cov(X)), digits=1)
round(solve(gmm$sigma), digits=1)


###################################################
### code chunk number 16: qpgraphSimulate.Rnw:341-342
###################################################
args(rHMgmm)


###################################################
### code chunk number 17: qpgraphSimulate.Rnw:351-360
###################################################
rHMgmm(dRegularMarkedGraphParam(pI=1, pY=3, d=2))
rHMgmm(matrix(c(0, 1, 0, 1,
                1, 0, 1, 0,
                0, 1, 0, 1,
                1, 0, 1, 0), nrow=4, byrow=TRUE), I=1)
rHMgmm(matrix(c(1, 2,
                2, 3,
                3, 4,
                4, 1), ncol=2, byrow=TRUE), I=1)


###################################################
### code chunk number 18: qpgraphSimulate.Rnw:370-373
###################################################
set.seed(12345)
gmm <- rHMgmm(dRegularMarkedGraphParam(pI=1, pY=3, d=2))
summary(gmm)


###################################################
### code chunk number 19: qpgraphSimulate.Rnw:378-391
###################################################
class(gmm)
names(gmm)
gmm$X
gmm$I
gmm$Y
gmm$p
gmm$pI
gmm$pY
gmm$g
gmm$mean()
gmm$sigma
gmm$a
gmm$eta2


###################################################
### code chunk number 20: hmgmm
###################################################
plot(gmm)


###################################################
### code chunk number 21: qpgraphSimulate.Rnw:417-418
###################################################
rcmvnorm(10, gmm)


###################################################
### code chunk number 22: qpgraphSimulate.Rnw:423-429
###################################################
set.seed(123)
X <- rcmvnorm(10000, gmm)
csigma <- (1/10000)*sum(X[, gmm$I] == 1)*cov(X[X[, gmm$I]==1, gmm$Y]) +
          (1/10000)*sum(X[, gmm$I] == 2)*cov(X[X[, gmm$I]==2, gmm$Y])
round(solve(csigma), digits=1)
round(solve(gmm$sigma), digits=1)


###################################################
### code chunk number 23: qpgraphSimulate.Rnw:434-439
###################################################
smean <- apply(X[, gmm$Y], 2, function(x, i) tapply(x, i, mean), X[, gmm$I])
smean
gmm$mean()
abs(smean[1, ] - smean[2, ])
gmm$a


###################################################
### code chunk number 24: qpgraphSimulate.Rnw:463-465
###################################################
eQTLcrossParam()
args(eQTLcrossParam)


###################################################
### code chunk number 25: qpgraphSimulate.Rnw:471-472
###################################################
reQTLcross(n=2, eQTLcrossParam())


###################################################
### code chunk number 26: qpgraphSimulate.Rnw:485-488
###################################################
data(map10, package="qtl")
class(map10)
head(lapply(map10, head))


###################################################
### code chunk number 27: qpgraphSimulate.Rnw:493-496
###################################################
eqtl <- reQTLcross(eQTLcrossParam(map=map10, genes=100))
class(eqtl)
eqtl


###################################################
### code chunk number 28: qpgraphSimulate.Rnw:503-504
###################################################
eqtl$model


###################################################
### code chunk number 29: geneticmap
###################################################
par(mfrow=c(1,2))
plot(map10)
plot(eqtl, main="eQTL model with cis-associations only")


###################################################
### code chunk number 30: qpgraphSimulate.Rnw:528-531
###################################################
set.seed(123)
eqtl <- reQTLcross(eQTLcrossParam(map=map10, genes=100,
                                  cis=0.5, trans=c(5, 5)), a=5)


###################################################
### code chunk number 31: qpgraphSimulate.Rnw:541-543
###################################################
head(ciseQTL(eqtl))
transeQTL(eqtl)


###################################################
### code chunk number 32: transeqtl
###################################################
plot(eqtl, main="eQTL model with trans-eQTL")


###################################################
### code chunk number 33: qpgraphSimulate.Rnw:563-566
###################################################
set.seed(123)
cross <- sim.cross(map10, eqtl)
cross


###################################################
### code chunk number 34: qpgraphSimulate.Rnw:580-585
###################################################
allcis <- ciseQTL(eqtl)
allcis[allcis$chrom==1, ]
gene <- allcis[2, "gene"]
chrom <- allcis[2, "chrom"]
location <- allcis[2, "location"]


###################################################
### code chunk number 35: qpgraphSimulate.Rnw:588-591
###################################################
connectedGenes <- graph::inEdges(gene, eqtl$model$g)[[1]]
connectedGenes <- connectedGenes[connectedGenes %in% eqtl$model$Y]
connectedGenes


###################################################
### code chunk number 36: qpgraphSimulate.Rnw:602-605
###################################################
library(qtl)

out.mr <- scanone(cross, method="mr", pheno.col=c(gene, connectedGenes))


###################################################
### code chunk number 37: lodprofiles
###################################################
plot(out.mr, chr=chrom, ylab="LOD score", lodcolumn=1:3, col=c("black", "blue", "red"), lwd=2)
abline(v=allcis[allcis$gene == gene, "location"])
legend("topright", names(out.mr)[3:5], col=c("black", "blue", "red"), lwd=2, inset=0.05)


###################################################
### code chunk number 38: qpgraphSimulate.Rnw:627-630
###################################################
out.perm <- scanone(cross, method="mr", pheno.col=c(gene, connectedGenes),
                    n.perm=100, verbose=FALSE)
summary(out.perm, alpha=c(0.05, 0.10))


###################################################
### code chunk number 39: qpgraphSimulate.Rnw:635-636
###################################################
summary(out.mr, perms=out.perm, alpha=0.05)


###################################################
### code chunk number 40: info
###################################################
toLatex(sessionInfo())


